# README

Persistent homology software.

# Website

<http://homcloud.dev/index.en.html>

# REQUIRE

HomCloud supports the following computing environments.

* Ubuntu (newer than 18.04 LTS)
* Debian (newer than buster)
* Linux with anaconda (miniconda3)
* Intel Mac with homebrew
* Apple Silicon Mac (M1) with miniforge3
* Windows (64bit)

Under any system, python 3.7 or newer versions are required.

# INSTALL

Please see the following install tutorial:

* Japanese: <https://homcloud.dev/install-guide/index.html>
* English: <https://homcloud.dev/install-guide/index.en.html>

## Notes

* If you don't want to install the software globally, please use virtualenv or venv.

# Upgrading HomCloud

See the following documents.

* Japanese <https://homcloud.dev/install-guide/index.html>
* English <https://homcloud.dev/install-guide/index.en.html>

# DOCUMENTS

Some tutorials of HomCloud are located at the following URLs.

* Japanese: <https://homcloud.dev/basic-usage.html>
* English: <https://homcloud.dev/basic-usage.en.html>

# Troubleshooting

See [FAQ](https://homcloud.dev/faq.html).

# AUTHORS

Ippei Obayashi and HomCloud development team.

## Contributors

* Tomohide Wada
* Tian Tunhua
* National Institute of Advanced Industrial Science and Technology (AIST)

